@@ -9,5 +9,5 @@ else:
 
 #Package Modules
 from .dataLoader import load_data_CSV, load_data_sklearn
-from .xaichooser import train_and_explainModel
-from .analyzer import compare_explanations
+from .hub import train_and_explainModel
+from .analyzer import compare_explanations, compare_explanationssinglef
